@@ -57,7 +57,7 @@ class BucketManager(MgrBase):
                 raise ValueError("Invalid limit")
         if prefix:
             options['prefix'] = urlsafe_base64_encode(prefix)
-        if mode:
+        if mode == 1 or mode == 0:
             options['mode'] = mode
         url = https_check(self._make_url('list', options))
         if options:
@@ -89,9 +89,7 @@ class BucketManager(MgrBase):
 
     def setdeadline(self, bucket, key, deadline):
         url = https_check('{0}/setdeadline'.format(self.mgr_host))
-        param = {
-            'bucket' : urlsafe_base64_encode(bucket),
-        }
+        param = { 'bucket' : urlsafe_base64_encode(bucket)}
         param['key'] = urlsafe_base64_encode(key) 
         param['deadline'] = deadline 
         body = super(BucketManager, self)._params_parse(param)
@@ -111,4 +109,3 @@ class BucketManager(MgrBase):
         debug('Now check storage of %s from %s to %s' % (name, startdate, enddate))
         return _get(url=url, headers=super(BucketManager, self)._gernerate_headers(url))
 
-        
