@@ -5,9 +5,13 @@ import os
 import requests
 from requests_toolbelt import MultipartEncoder
 from wcs.commons.http import _post
+from os.path import expanduser
 from wcs.commons.logme import debug,error
 from wcs.commons.util import https_check
 
+from wcs.commons.config import Config
+config_file = os.path.join(expanduser("~"), ".wcscfg")
+
 class SimpleUpload(object):
     """普通上传类
     该类实现了WCS的普通上传功能
@@ -32,9 +36,13 @@ class SimpleUpload(object):
         return open(path, 'rb')
 
     def _upload(self,url,encoder,headers,f):
+        cfg = Config(config_file)
         url = https_check(url)
         try:
-            r = requests.post(url=url, headers=headers, data=encoder, verify=True)
+            if cfg.isverify:
+                r = requests.post(url=url, headers=headers, data=encoder, verify=True)
+            else:
+                r = requests.post(url=url, headers=headers, data=encoder, verify=False)
         except Exception as e:
             f.close()
             debug('Request url:' + url)
